Crate boltffi_core

Crate boltffi_core 

Re-exports

pub use callback::ArcFromCallbackHandle;
pub use callback::BoxFromCallbackHandle;
pub use callback::CallbackForeignType;
pub use callback::CallbackHandle;
pub use callback::NativeCallbackOwner;
pub use custom_ffi::CustomFfiConvertible;
pub use handle::HandleBox;
pub use passable::Passable;
pub use passable::VecTransport;
pub use passable::WirePassable;
pub use ringbuffer::SpscRingBuffer;
pub use runtime::async_callback;
pub use runtime::async_callback::AsyncCallback;
pub use runtime::async_callback::AsyncCallbackCompletion;
pub use runtime::async_callback::AsyncCallbackCompletionCode;
pub use runtime::async_callback::AsyncCallbackCompletionResult;
pub use runtime::async_callback::AsyncCallbackRegistry;
pub use runtime::async_callback::AsyncCallbackRequestGuard;
pub use runtime::async_callback::AsyncCallbackRequestId;
pub use runtime::async_callback::AsyncCallbackString;
pub use runtime::async_callback::AsyncCallbackVoid;
pub use runtime::future as rustfuture;
pub use runtime::future::RustFuture;
pub use runtime::future::RustFutureContinuationCallback;
pub use runtime::future::RustFutureHandle;
pub use runtime::future::RustFuturePoll;
pub use runtime::pending;
pub use runtime::pending::CancellationToken;
pub use runtime::pending::PendingHandle;
pub use runtime::subscription;
pub use runtime::subscription::EventSubscription;
pub use runtime::subscription::StreamContinuationCallback;
pub use runtime::subscription::StreamPollResult;
pub use runtime::subscription::StreamProducer;
pub use runtime::subscription::SubscriptionHandle;
pub use runtime::subscription::WaitResult;
pub use safety::catch_ffi_panic;
pub use status::FfiStatus;
pub use status::clear_last_error;
pub use status::set_last_error;
pub use status::take_last_error;
pub use types::FfiBuf;
pub use types::FfiError;
pub use types::FfiOption;
pub use types::FfiSlice;
pub use types::FfiSpan;
pub use types::FfiString;
pub use wasm::WASM_ABI_VERSION;

Modules

callback
Callback handle and ownership contracts used by generated foreign bindings.
custom_ffi
handle
passable
Defines the FFI input and output types used for Rust values.
ringbuffer
runtime
safety
status
types
wasm
wire

Macros

custom_type

Structs

CustomTypeConversionError
UnexpectedFfiCallbackError

Functions

boltffi_clear_last_error
boltffi_free_string
boltffi_last_error_message
fail_with_error

Attribute Macros

custom_ffi
data
default
error
export
ffi_export
ffi_stream
ffi_trait
name
skip

Derive Macros

Data
FfiType